@@ -1,19 +1,20 @@
 #!/usr/bin/env python3
 """
-Sync lazy iterator example.
+Lazy Iterator
 
-Shows the difference between .list() and .iter()
+Difference between .list() and .iter()
+
+Note: Set HOPX_API_KEY environment variable before running.
 """
 
+import os
 from hopx_ai import Sandbox
 
-API_KEY = "hopx_f0dfeb804627ca3c1ccdd3d43d2913c9"
-
-print("📊 Iterator vs List Comparison\n")
+print("Iterator vs List Comparison\n")
 
 # Method 1: .list() - loads ALL into memory
 print("1. Using .list() (loads all into memory):")
-sandboxes = Sandbox.list(api_key=API_KEY)
+sandboxes = Sandbox.list()
 print(f"   Loaded {len(sandboxes)} sandboxes into memory")
 for sb in sandboxes[:3]:
     info = sb.get_info()
@@ -22,14 +23,14 @@ for sb in sandboxes[:3]:
 # Method 2: .iter() - lazy loading (better for large lists)
 print("\n2. Using .iter() (lazy loading):")
 count = 0
-for sandbox in Sandbox.iter(api_key=API_KEY):
+for sandbox in Sandbox.iter():
     info = sandbox.get_info()
     print(f"   • {sandbox.sandbox_id}: {info.status}")
     count += 1
-    
+
     if count >= 3:  # Stop early
-        print("   (stopping early - remaining pages not fetched!)")
+        print("   (stopping early - remaining pages not fetched)")
         break
 
-print("\n✅ With .iter(), you can break early and save API calls!")
+print("\nWith .iter(), you can break early and save API calls")
 
