@@ -1,6 +1,8 @@
 #!/usr/bin/env python3
 """
-Quick start - create your first sandbox in seconds.
+Quick Start
+
+Create your first sandbox in seconds.
 
 Before running:
     export HOPX_API_KEY="hopx_your_key_here"
@@ -10,21 +12,22 @@ Or pass api_key directly to Sandbox.create()
 
 from hopx_ai import Sandbox
 
-print("🚀 HOPX.AI Quick Start\n")
+print("Quick Start\n")
 
 # Create sandbox (API key from HOPX_API_KEY env var)
 print("Creating sandbox...")
 sandbox = Sandbox.create(template="code-interpreter")
-print(f"✅ Created: {sandbox.sandbox_id}")
+print(f"Created: {sandbox.sandbox_id}")
 
 # Get info
 info = sandbox.get_info()
-print(f"🌐 URL: {info.public_host}")
-print(f"📊 Status: {info.status}")
-print(f"💾 Resources: {info.vcpu} vCPU, {info.memory_mb}MB RAM")
+print(f"URL: {info.public_host}")
+print(f"Status: {info.status}")
+if info.resources:
+    print(f"Resources: {info.resources.vcpu} vCPU, {info.resources.memory_mb}MB RAM")
 
 # Cleanup
 print("\nCleaning up...")
 sandbox.kill()
-print("✅ Done!")
+print("Done")
 
