@@ -5,18 +5,18 @@ Official Python client for Hopx Sandboxes.
 
 Sync Example:
     >>> from hopx_ai import Sandbox
-    >>> 
+    >>>
     >>> # Create sandbox
     >>> sandbox = Sandbox.create(template="code-interpreter")
     >>> print(sandbox.get_info().public_host)
-    >>> 
+    >>>
     >>> # Cleanup
     >>> sandbox.kill()
 
 Async Example:
     >>> from hopx_ai import AsyncSandbox
-    >>> 
-    >>> async with AsyncSandbox.create(template="nodejs") as sandbox:
+    >>>
+    >>> async with AsyncSandbox.create(template="code-interpreter") as sandbox:
     ...     info = await sandbox.get_info()
     ...     print(f"Running at: {info.public_host}")
     # Automatically killed when exiting context
@@ -32,6 +32,7 @@ from .models import (
     CommandResult,
     FileInfo,
     RichOutput,
+    ExpiryInfo,
     # Desktop models
     VNCInfo,
     WindowInfo,
@@ -56,7 +57,16 @@ from .errors import (
     CodeExecutionError,
     CommandExecutionError,
     DesktopNotAvailableError,
+    # Sandbox lifecycle errors
+    SandboxExpiredError,
+    TokenExpiredError,
+    SandboxErrorMetadata,
+    # Template errors
+    TemplateBuildError,
+    TemplateBuildErrorMetadata,
+    TemplateNotFoundError,
 )
+
 # Template Building
 from .template import (
     Template,
@@ -68,7 +78,7 @@ from .template import (
     wait_for_command,
 )
 
-__version__ = "0.2.0"
+__version__ = "0.3.8"
 __all__ = [
     "Sandbox",
     "AsyncSandbox",
@@ -79,6 +89,7 @@ __all__ = [
     "CommandResult",
     "FileInfo",
     "RichOutput",
+    "ExpiryInfo",
     # Desktop models
     "VNCInfo",
     "WindowInfo",
@@ -102,6 +113,14 @@ __all__ = [
     "CodeExecutionError",
     "CommandExecutionError",
     "DesktopNotAvailableError",
+    # Sandbox lifecycle errors
+    "SandboxExpiredError",
+    "TokenExpiredError",
+    "SandboxErrorMetadata",
+    # Template errors
+    "TemplateBuildError",
+    "TemplateBuildErrorMetadata",
+    "TemplateNotFoundError",
     # Template Building
     "Template",
     "create_template",
@@ -111,4 +130,3 @@ __all__ = [
     "wait_for_process",
     "wait_for_command",
 ]
-
